#include <kaboutdata.h>
#include <kapplication.h>
#include <kcmdlineargs.h>
#include <kdebug.h>
#include <klibloader.h>
#include <klocale.h>
#include <kmessagebox.h>
#include <kstdaction.h>

#include "krichtexteditpart.h"

#include "krichtextedit.h"
#include "krichtextedit.moc"

KRichTextEdit::KRichTextEdit()
    : KParts::MainWindow( 0, "rich_text_edit" )
{
    (void) KStdAction::quit( qApp, SLOT( quit() ), actionCollection() );

    KLibFactory *factory = KLibLoader::self()->factory("libkrichtexteditpart");
    if ( !factory ) {
        KMessageBox::error( this, "Could not load editor library!" );
        kapp->quit();
    }

    KRichTextEditPart *part = static_cast<KRichTextEditPart *>( factory->create( this, "krichtexteditpart",
								  "KParts::ReadWritePart" ) );
    if ( !part ) {
        KMessageBox::error( this, "Could not create editor part!" );
        kapp->quit();
    }

    // tell the KParts::MainWindow that this is indeed the main widget
    setCentralWidget( part->widget() );
            
    // and integrate the part's GUI with the shell's
    setXMLFile( "krichtexteditui.rc" );
    createGUI( part );
}

KRichTextEdit::~KRichTextEdit()
{

}

int main( int argc, char **argv )
{
    static KCmdLineOptions options[] = {
        { "+file", I18N_NOOP( "A filename" ), 0 },
        { 0, 0, 0 }
    };

    KAboutData about("krichtextedit", I18N_NOOP("KRichTextEditor"), "0.1",
		     I18N_NOOP("A Simple Rich Text Editor"),
                     KAboutData::License_LGPL,
		     I18N_NOOP("(c) 2002 Richard Moore"));
    KCmdLineArgs::init(argc, argv, &about);
    KCmdLineArgs::addCmdLineOptions( options );
    KApplication app;

    kdDebug() << "Creating main window" << endl;

    KRichTextEdit *win = new KRichTextEdit();
    win->resize( 600, 450 );
    app.setMainWidget( win );
    app.connect( &app, SIGNAL( lastWindowClosed() ), SLOT( quit() ) );

    kdDebug() << "Processing arguments" << endl;
    KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
    if ( args->count() ) {
      kdDebug() << "Got a filename, loading" << endl;
//      win->openURL( args->url(0) );
    }

    kdDebug() << "Showing main window" << endl;
    win->show();

    kdDebug() << "Starting event loop" << endl;
    return app.exec();
}

// Local Variables:
// c-basic-offset: 4
// End:
